"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SlimNodeMySQLPool = void 0;
const promise_1 = require("mysql2/promise");
const PreparedStatement_1 = require("./PreparedStatement");
class SlimNodeMySQLPool {
    constructor(config) {
        if (typeof config === 'string') {
            this.parseConnectionString(config);
        }
        else {
            this.pool = (0, promise_1.createPool)(config);
        }
    }
    parseConnectionString(connectionString) {
        let host;
        let user;
        let password;
        let database;
        if (typeof connectionString === 'string') {
            try {
                const parts = connectionString.replace('mysql://', '').split('@');
                [user, password] = parts[0].split(':');
                [host, database] = parts[1].split('/');
                database = database.slice(0, database.indexOf('?'));
            }
            catch (error) {
                throw new Error('Invalid connection string: ' + error);
            }
        }
        else {
            ({ host, user, password, database } = connectionString);
        }
        this.pool = (0, promise_1.createPool)({
            connectionLimit: 10,
            waitForConnections: true,
            host,
            user,
            password,
            database,
        });
    }
    query(sql, parameters) {
        if (parameters) {
            const preparedStatement = new PreparedStatement_1.PreparedStatement(sql, parameters);
            const { preparedSql, preparedValues } = preparedStatement.prepare();
            return this.promiseQuery(preparedSql, preparedValues);
        }
        return this.promiseQuery(sql);
    }
    promiseQuery(sql, preparedValues) {
        return __awaiter(this, void 0, void 0, function* () {
            const [data, fields] = yield this.pool.query(sql, preparedValues);
            const queryResult = data;
            if (Array.isArray(data)) {
                queryResult._fields = fields;
            }
            return queryResult;
        });
    }
    close() {
        var _a;
        (_a = this.pool) === null || _a === void 0 ? void 0 : _a.end();
    }
}
exports.SlimNodeMySQLPool = SlimNodeMySQLPool;
//# sourceMappingURL=SlimNodeMySQLPool.js.map